@@ -19,7 +19,7 @@ import sys
 from util import ip
 from util.cache import Cache
 
-__version__ = "v2.9.7@2020-09-11T03:24:57+00:00"  # CI 时会被Tag替换
+__version__ = "v2.9.9@2021-04-13T03:59:42+00:00"  # CI 时会被Tag替换
 __description__ = "automatically update DNS records to dynamic local IP [自动更新DNS记录指向本地IP]"
 __doc__ = """
 ddns[%s]
@@ -28,7 +28,7 @@ ddns[%s]
 Copyright (c) New Future (MIT License)
 """ % (__version__)
 
-environ["DDNS_VERSION"] = "v2.9.7"
+environ["DDNS_VERSION"] = "v2.9.9"
 
 if getattr(sys, 'frozen', False):
     # https://github.com/pyinstaller/pyinstaller/wiki/Recipe-OpenSSL-Certificate
@@ -52,7 +52,7 @@ def get_config(key=None, default=None, path="config.json"):
             with open(path, 'w') as configfile:
                 configure = {
                     "$schema": "https://ddns.newfuture.cc/schema/v2.8.json",
-                    "id": "YOUR ID or EAMIL for DNS Provider",
+                    "id": "YOUR ID or EMAIL for DNS Provider",
                     "token": "YOUR TOKEN or KEY for DNS Provider",
                     "dns": "dnspod",
                     "ipv4": [
@@ -70,7 +70,8 @@ def get_config(key=None, default=None, path="config.json"):
                     "debug": False,
                 }
                 dumpjson(configure, configfile, indent=2, sort_keys=True)
-            sys.exit("New template configure file `%s` is generated." % path)
+            sys.stdout.write("New template configure file `%s` is generated.\n" % path)
+            sys.exit(1)
         except:
             sys.exit('fail to load config from file: %s' % path)
     if key:
